# cesium-script

---


**Source Code**: [https://juigitlab.esac.esa.int/core-system/uplink/auxiliary-tools/cesium-script.git](https://juigitlab.esac.esa.int/core-system/uplink/auxiliary-tools/cesium-script.git)

---

Collection of scripts and utils to generate inputs for the Cesium based JUICE SOC tool  [https://juicesoc.esac.esa.int/cesium/](https://juicesoc.esac.esa.int/cesium/)

## Installation

```sh
pip install cesium-script
```

## Development

* Clone this repository
* Requirements:
  * [Poetry](https://python-poetry.org/)
  * Python 3.9+
* Create a virtual environment and install the dependencies

```sh
poetry install
```

* Activate the virtual environment

```sh
poetry shell
```

### Testing

```sh
pytest
```

### Documentation

The documentation is automatically generated from the content of the [docs directory](./docs) and from the docstrings
 of the public signatures of the source code.

### Pre-commit

Pre-commit hooks run all the auto-formatters (e.g. `black`, `isort`), linters (e.g. `mypy`, `flake8`), and other quality
 checks to make sure the changeset is in good shape before a commit/push happens.

You can install the hooks with (runs for each commit):

```sh
pre-commit install
```

Or if you want them to run only for each push:

```sh
pre-commit install -t pre-push
```

Or if you want e.g. want to run all checks manually for all files:

```sh
pre-commit run --all-files
```

### Build
```sh
poetry build
```

### Publishing to JUICE NEXUS repository
#### Setting up the remote JUICE SOC private repository (First time only)
```sh
poetry config repositories.packagr  https://scidockreg.esac.esa.int/repository/pypi-juice-releases/
poetry config http-basic.packagr <user>
```
#### Publishing
```sh
poetry publish -r packagr
```

## Package Usage

### Command line stand-alone application
The python package provides a command line tool as entry point for the basic functionality.
```sh
usage: generate_scene [-h] -mk METAKERNEL -b BODY -st START_UTC -et END_UTC -s STEP

Creates a CZML file containing the contextual information of the S/C (position and attitude)

optional arguments:
  -h, --help            show this help message and exit
  -mk METAKERNEL, --metakernel METAKERNEL
                        the path to metakernel
  -b BODY, --body BODY  Central body name. eg: Europa
  -st START_UTC, --start_utc START_UTC
                        Scene start using UTC scale and ISO format (e.g. 2032-07-02T14:22:25Z)
  -et END_UTC, --end_utc END_UTC
                        Scene end using UTC scale and ISO format (e.g. 2032-07-02T19:32:17Z)
  -s STEP, --step STEP  Step size for SPICE calculations in seconds. Optional - The tool will decide the step size.
```

e.g.

```sh
$ generate_scene -mk ~/juice_repo/juice_crema_5_1_150lb_v420_20221220_001.tm -st 2032-07-02T14:22:25Z -et 2032-07-02T19:32:17Z -s 5 -b Europa
2023-05-11 10:20:36,947[INFO] CZML generated
2023-05-11 10:20:37,945[INFO] jui_eur_20320702T1422_20320702T1932.czml generated
```



### Integration with Jupyter Notebooks
The cesium_script package can be used as part of Jupyter Notebook scripting

#### How to install the cesium_script in my Jupyter environment?

Go to `File > New > Notebook` to create a new notebook and in the first cell, type:
```python
%pip install --upgrade cesium_script
```

Execute the cell with <kbd>⇧ Shift</kbd> + <kbd>↵ Enter</kbd> and you should get the latest version of the `cesium_script`.

You can double check which version was install with the command:
```python
%pip show cesium_script
```

#### A quick Jupyter notebook sample

Pre-requiste: A valid ESAC SPICE service local metakernel covering the Jupiter Tour ()

```python
from cesium_script.czml.scene import generate_czml
import spiceypy as sp

sp.kclear()
sp.furnsh('<HERE_PATH_TO _METAKERNEL>')
czml = generate_czml('2032-07-02T14:22:25Z', '2032-07-02T16:22:25Z', 60, 'Europa')
with open('sample.czml', 'w+') as czml_file:
    czml.dump(czml_file, indent=2)
```

### Checking the results

Once the CZML has been generated, it can be loaded as an input of the https://juicesoc.esac.esa.int/cesium/ tool.
1. Select the central body from the top/left selector
1. Open the dataset load area clicking the left central chevron
1. Click the "Load Data" button
1. Upload the file using either the browse or drag&drop options

---

This project was generated using the [wolt-python-package-cookiecutter](https://github.com/woltapp/wolt-python-package-cookiecutter) template.
